/***************************************************************************
                          rpainter.h  -  description
                             -------------------
    begin                : Mon Sep 27 1999
    copyright            : (C) 1999 by Andreas Mustun
    email                : andrew@ribbonsoft.com
 ***************************************************************************/

/****************************************************************************
** rpainter.h 1998/08/27 A. Mustun RibbonSoft 
**
** Copyright (C) 1998 RibbonSoft.  All rights reserved.
**
*****************************************************************************/

#ifndef RPAINTER_H
#define RPAINTER_H

#include <qpainter.h>

class RPainter : public QPainter
{
public:
  RPainter();
  RPainter( const QPaintDevice* _pDev );
  ~RPainter();

  void drawExactArc( double _cx, double _cy,
                     double _cr,
                     double _a1, double _a2,
                     int   _x1, int   _y1,
                     int   _x2, int   _y2,
                     bool _reversed );

  void drawStyleLine( int _x1, int _y1,
                      int _x2, int _y2,
                      int _width=1,
                      PenStyle _style=SolidLine );
    
private:

};


#endif

// EOF


